@@ -123,6 +123,11 @@ class BaseSnatch:
         logger.info(f"Calling {url}...")
         return self._request_and_create_data(url=url, timeout=timeout)
 
+    def get_from_id(self, id: int, timeout: int = None) -> BaseData:
+        url = f"/api/prospects/{id}/"
+        logger.info(f"Calling {url}...")
+        return self._request_and_create_data(url=url, timeout=timeout)
+
     def _format_response(self, data: Dict[Any, Any]) -> BaseData:
         data_obj = self.serializer_class().load(data)
         data_obj.current_environment = self.settings["current_environment"]
